# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.apimanagement import ApiManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestApiManagementWorkspaceApiDiagnosticOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(ApiManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_diagnostic_list_by_workspace(self, resource_group):
        response = self.client.workspace_api_diagnostic.list_by_workspace(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            api_version="2024-05-01",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_diagnostic_get_entity_tag(self, resource_group):
        response = self.client.workspace_api_diagnostic.get_entity_tag(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            diagnostic_id="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_diagnostic_get(self, resource_group):
        response = self.client.workspace_api_diagnostic.get(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            diagnostic_id="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_diagnostic_create_or_update(self, resource_group):
        response = self.client.workspace_api_diagnostic.create_or_update(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            diagnostic_id="str",
            parameters={
                "alwaysLog": "str",
                "backend": {
                    "request": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                    "response": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                },
                "frontend": {
                    "request": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                    "response": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                },
                "httpCorrelationProtocol": "str",
                "id": "str",
                "logClientIp": bool,
                "loggerId": "str",
                "metrics": bool,
                "name": "str",
                "operationNameFormat": "str",
                "sampling": {"percentage": 0.0, "samplingType": "str"},
                "type": "str",
                "verbosity": "str",
            },
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_diagnostic_update(self, resource_group):
        response = self.client.workspace_api_diagnostic.update(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            diagnostic_id="str",
            if_match="str",
            parameters={
                "alwaysLog": "str",
                "backend": {
                    "request": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                    "response": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                },
                "frontend": {
                    "request": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                    "response": {
                        "body": {"bytes": 0},
                        "dataMasking": {
                            "headers": [{"mode": "str", "value": "str"}],
                            "queryParams": [{"mode": "str", "value": "str"}],
                        },
                        "headers": ["str"],
                    },
                },
                "httpCorrelationProtocol": "str",
                "id": "str",
                "logClientIp": bool,
                "loggerId": "str",
                "metrics": bool,
                "name": "str",
                "operationNameFormat": "str",
                "sampling": {"percentage": 0.0, "samplingType": "str"},
                "type": "str",
                "verbosity": "str",
            },
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_workspace_api_diagnostic_delete(self, resource_group):
        response = self.client.workspace_api_diagnostic.delete(
            resource_group_name=resource_group.name,
            service_name="str",
            workspace_id="str",
            api_id="str",
            diagnostic_id="str",
            if_match="str",
            api_version="2024-05-01",
        )

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential
from azure.mgmt.azurestack import AzureStackManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-azurestack
# USAGE
    python patch.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = AzureStackManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="dd8597b4-8739-4467-8b10-f8679f62bfbf",
    )

    response = client.registrations.update(
        resource_group="azurestack",
        registration_name="testregistration",
        token={
            "location": "global",
            "properties": {
                "registrationToken": "EyjIAWXSAw5nTw9KZWWiOiJeZxZlbg9wBwvUdCiSIM9iaMVjdeLkijoinwIzyJa2Ytgtowm2yy00OdG4lTlLyJmtztHjZGfJZTC0NZK1iIWiY2XvdWRJzCi6iJy5nDy0oDk1LTNHmWeTnDUwyS05oDI0LTrINzYwoGq5mjAzziIsim1HCmtldHBsYwnLu3LuZGljYXrpB25FBmfIbgVkIJp0CNvLLCJOYXJkd2FYzuLUZM8iOlt7IM51bunvcMVZiJoYlCjcaw9ZiJPBIjNkzDJHmda3yte5ndqZMdq4YmZkZmi5oDM3OTY3ZwNMIL0SIM5PyYI6WyJLZTy0ztJJMwZKy2m0OWNLODDLMwm2zTm0ymzKyjmWySisiJA3njlHmtdlY2q4NjRjnwFIZtC1YZi5ZGyZodM3Y2vjIl0siMnwDsi6wyi2oDUZoTbiY2RhNDa0ymrKoWe4YtK5otblzWrJzGyzNCISIjmYnzC4M2vmnZdIoDRKM2i5ytfkmJlhnDc1zdhLzWm1il0sim5HBwuiOijIqzF1MTvhmDIXmIIsimrpc2SiolsioWNlZjVhnZM1otQ0nDu3NmjlN2M3zmfjzmyZMTJhZtiiLcjLZjLmmZJhmWVhytG0NTu0OTqZNWu1Mda0MZbIYtfjyijdLCj1DWlKijoinwM5Mwu3NjytMju5Os00oTIwlWi0OdmTnGzHotiWm2RjyTCxIIwiBWvTb3J5ijPbijAYZDA3M2fjNzu0YTRMZTfhodkxzDnkogY5ZtAWzdyXIiwINZcWzThLnDQ4otrJndAzZGI5MGzlYtY1ZJA5ZdfiNMQIXX1DlcJpC3n1zxiiOijZb21lB25LIIWIdmVyC2LVbiI6IJeuMcJ9"
            },
        },
    )
    print(response)


# x-ms-original-file: specification/azurestack/resource-manager/Microsoft.AzureStack/stable/2022-06-01/examples/Registration/Patch.json
if __name__ == "__main__":
    main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential
from azure.mgmt.devhub import DevHubMgmtClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-devhub
# USAGE
    python workflow_create_or_update.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = DevHubMgmtClient(
        credential=DefaultAzureCredential(),
        subscription_id="subscriptionId1",
    )

    response = client.workflow.create_or_update(
        resource_group_name="resourceGroup1",
        workflow_name="workflow1",
        parameters={
            "location": "location1",
            "properties": {
                "githubWorkflowProfile": {
                    "acr": {
                        "acrRegistryName": "registry1",
                        "acrRepositoryName": "repo1",
                        "acrResourceGroup": "resourceGroup1",
                        "acrSubscriptionId": "subscriptionId1",
                    },
                    "aksResourceId": "/subscriptions/subscriptionId1/resourcegroups/resourceGroup1/providers/Microsoft.ContainerService/managedClusters/cluster1",
                    "branchName": "branch1",
                    "deploymentProperties": {
                        "kubeManifestLocations": ["/src/manifests/"],
                        "manifestType": "kube",
                        "overrides": {"key1": "value1"},
                    },
                    "dockerBuildContext": "repo1/src/",
                    "dockerfile": "repo1/images/Dockerfile",
                    "namespace": "namespace1",
                    "oidcCredentials": {
                        "azureClientId": "12345678-3456-7890-5678-012345678901",
                        "azureTenantId": "66666666-3456-7890-5678-012345678901",
                    },
                    "repositoryName": "repo1",
                    "repositoryOwner": "owner1",
                }
            },
            "tags": {"appname": "testApp"},
        },
    )
    print(response)


# x-ms-original-file: specification/developerhub/resource-manager/Microsoft.DevHub/preview/2022-10-11-preview/examples/Workflow_CreateOrUpdate.json
if __name__ == "__main__":
    main()



# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: send_template_notification_messages.py

DESCRIPTION:
    This sample demonstrates sending an Whatsapp template message from business phone number to a single user. 
    Template to be used in the sample needs to be created in WhatsApp Business account first.
    Follow the instructions in the Meta Business Help Center at https://www.facebook.com/business/help/2055875911147364?id=2129163877102343.
    The NotificationMessageClient is authenticated using a connection string.
USAGE:
    python send_template_notification_messages.py

    Set the environment variable with your own value before running the sample:
    1) COMMUNICATION_SAMPLES_CONNECTION_STRING - the connection string in your ACS resource
    2) RECIPIENT_PHONE_NUMBER - a phone number with Whatsapp capabilities. Use list for recipient phone number.
    3) WHATSAPP_CHANNEL_ID - Channel created in Azure portal for Advanced Messaging.
"""

import os
import sys

sys.path.append("..")


class SendWhatsAppTemplateMessageSample(object):

    connection_string = os.getenv("COMMUNICATION_SAMPLES_CONNECTION_STRING")
    phone_number = os.getenv("RECIPIENT_PHONE_NUMBER")
    channel_id = os.getenv("WHATSAPP_CHANNEL_ID")

    def send_template_send_message(self):

        from azure.communication.messages import NotificationMessagesClient
        from azure.communication.messages.models import TemplateNotificationContent, MessageTemplate

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)

        # Setting template options
        input_template: MessageTemplate = MessageTemplate(name="cpm_welcome", language="en_us")

        template_options = TemplateNotificationContent(
            channel_registration_id=self.channel_id, to=[self.phone_number], template=input_template
        )

        # calling send() with whatsapp message details
        message_responses = messaging_client.send(template_options)
        response = message_responses.receipts[0]
        print("Message with message id {} was successful sent to {}".format(response.message_id, response.to))

    def send_template_message_with_parameters(self):

        from azure.communication.messages import NotificationMessagesClient
        from azure.communication.messages.models import (
            TemplateNotificationContent,
            MessageTemplate,
            MessageTemplateText,
            WhatsAppMessageTemplateBindings,
            WhatsAppMessageTemplateBindingsComponent,
        )

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)

        # Setting template options
        templateName = "sample_shipping_confirmation"
        templateLanguage = "en_us"
        shippingConfirmationTemplate: MessageTemplate = MessageTemplate(name=templateName, language=templateLanguage)
        threeDays = MessageTemplateText(name="threeDays", text="3")
        bindings = WhatsAppMessageTemplateBindings(
            body=[WhatsAppMessageTemplateBindingsComponent(ref_value=threeDays.name)]
        )
        shippingConfirmationTemplate.bindings = bindings
        shippingConfirmationTemplate.template_values = [threeDays]
        template_options = TemplateNotificationContent(
            channel_registration_id=self.channel_id, to=[self.phone_number], template=shippingConfirmationTemplate
        )

        # calling send() with whatsapp message details
        message_responses = messaging_client.send(template_options)
        response = message_responses.receipts[0]
        print("Message with message id {} was successful sent to {}".format(response.message_id, response.to))

    def send_template_message_with_buttons(self):

        from azure.communication.messages import NotificationMessagesClient
        from azure.communication.messages.models import (
            TemplateNotificationContent,
            MessageTemplate,
            MessageTemplateText,
            WhatsAppMessageTemplateBindings,
            WhatsAppMessageTemplateBindingsComponent,
            MessageTemplateQuickAction,
            WhatsAppMessageTemplateBindingsButton,
            WhatsAppMessageButtonSubType,
        )

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)

        # Setting template options
        templateName = "sample_issue_resolution"
        templateLanguage = "en_us"
        shippingConfirmationTemplate: MessageTemplate = MessageTemplate(name=templateName, language=templateLanguage)
        name = MessageTemplateText(name="first", text="Joe")
        yes = MessageTemplateQuickAction(name="Yes", payload="Joe said yes")
        no = MessageTemplateQuickAction(name="No", payload="Joe said no")
        bindings = WhatsAppMessageTemplateBindings(body=[WhatsAppMessageTemplateBindingsComponent(ref_value=name.name)])
        bindings.buttons = [
            WhatsAppMessageTemplateBindingsButton(
                sub_type=WhatsAppMessageButtonSubType.QUICK_REPLY, ref_value=yes.name
            ),
            WhatsAppMessageTemplateBindingsButton(sub_type=WhatsAppMessageButtonSubType.QUICK_REPLY, ref_value=no.name),
        ]
        shippingConfirmationTemplate.bindings = bindings
        shippingConfirmationTemplate.template_values = [name, yes, no]
        template_options = TemplateNotificationContent(
            channel_registration_id=self.channel_id, to=[self.phone_number], template=shippingConfirmationTemplate
        )

        # calling send() with whatsapp message details
        message_responses = messaging_client.send(template_options)
        response = message_responses.receipts[0]
        print("Message with message id {} was successful sent to {}".format(response.message_id, response.to))

    def send_template_message_with_media(self):

        from azure.communication.messages import NotificationMessagesClient
        from azure.communication.messages.models import (
            TemplateNotificationContent,
            MessageTemplate,
            MessageTemplateText,
            WhatsAppMessageTemplateBindings,
            WhatsAppMessageTemplateBindingsComponent,
            MessageTemplateImage,
        )

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)

        # Setting template options
        templateName = "sample_movie_ticket_confirmation"
        templateLanguage = "en_us"
        imageUrl = "https://aka.ms/acsicon1"
        sample_movie_ticket_confirmation: MessageTemplate = MessageTemplate(
            name=templateName, language=templateLanguage
        )
        image = MessageTemplateImage(name="image", url=imageUrl)
        title = MessageTemplateText(name="title", text="Contoso")
        time = MessageTemplateText(name="time", text="July 1st, 2023 12:30PM")
        venue = MessageTemplateText(name="venue", text="Southridge Video")
        seats = MessageTemplateText(name="seats", text="Seat 1A")

        bindings = WhatsAppMessageTemplateBindings(
            header=[WhatsAppMessageTemplateBindingsComponent(ref_value=image.name)],
            body=[
                WhatsAppMessageTemplateBindingsComponent(ref_value=title.name),
                WhatsAppMessageTemplateBindingsComponent(ref_value=time.name),
                WhatsAppMessageTemplateBindingsComponent(ref_value=venue.name),
                WhatsAppMessageTemplateBindingsComponent(ref_value=seats.name),
            ],
        )

        sample_movie_ticket_confirmation.bindings = bindings
        sample_movie_ticket_confirmation.template_values = [image, title, time, venue, seats]
        template_options = TemplateNotificationContent(
            channel_registration_id=self.channel_id, to=[self.phone_number], template=sample_movie_ticket_confirmation
        )

        # calling send() with whatsapp message details
        message_responses = messaging_client.send(template_options)
        response = message_responses.receipts[0]
        print("Message with message id {} was successful sent to {}".format(response.message_id, response.to))

    def send_template_message_with_call_to_action(self):

        from azure.communication.messages import NotificationMessagesClient
        from azure.communication.messages.models import (
            TemplateNotificationContent,
            MessageTemplate,
            MessageTemplateText,
            WhatsAppMessageTemplateBindings,
            WhatsAppMessageTemplateBindingsComponent,
            MessageTemplateQuickAction,
            MessageTemplateImage,
            WhatsAppMessageTemplateBindingsButton,
            WhatsAppMessageButtonSubType,
        )

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)

        # Setting template options
        templateName = "purchase_feedback"
        templateLanguage = "en_us"
        imageUrl = "https://aka.ms/acsicon1"
        sample_purchase_feedback: MessageTemplate = MessageTemplate(name=templateName, language=templateLanguage)
        name = MessageTemplateText(name="first", text="Joe")
        image = MessageTemplateImage(name="image", url=imageUrl)
        uri_to_click = MessageTemplateQuickAction(name="url", text="questions")

        bindings = WhatsAppMessageTemplateBindings(
            body=[WhatsAppMessageTemplateBindingsComponent(ref_value=name.name)],
            header=[WhatsAppMessageTemplateBindingsComponent(ref_value=image.name)],
            buttons=[
                WhatsAppMessageTemplateBindingsButton(
                    sub_type=WhatsAppMessageButtonSubType.URL, ref_value=uri_to_click.name
                )
            ],
        )
        sample_purchase_feedback.bindings = bindings
        sample_purchase_feedback.template_values = [name, image, uri_to_click]
        template_options = TemplateNotificationContent(
            channel_registration_id=self.channel_id, to=[self.phone_number], template=sample_purchase_feedback
        )

        # calling send() with whatsapp message details
        message_responses = messaging_client.send(template_options)
        response = message_responses.receipts[0]
        print(
            "WhatsApp Call To Action Templated Message with message id {} was successfully sent to {}".format(
                response.message_id, response.to
            )
        )

    def send_template_message_with_location(self):

        from azure.communication.messages import NotificationMessagesClient
        from azure.communication.messages.models import (
            TemplateNotificationContent,
            MessageTemplate,
            MessageTemplateText,
            WhatsAppMessageTemplateBindings,
            WhatsAppMessageTemplateBindingsComponent,
            MessageTemplateLocation,
        )

        messaging_client = NotificationMessagesClient.from_connection_string(self.connection_string)

        # Setting template options
        templateName = "sample_movie_location"
        templateLanguage = "en_us"
        sample_movie_location: MessageTemplate = MessageTemplate(name=templateName, language=templateLanguage)
        name = MessageTemplateText(name="first", text="Joe")
        location = MessageTemplateLocation(
            name="location",
            location_name="Pablo Morales",
            address="1 Hacker Way, Menlo Park, CA 94025",
            latitude=37.483307,
            longitude=122.148981,
        )
        bindings = WhatsAppMessageTemplateBindings(
            body=[WhatsAppMessageTemplateBindingsComponent(ref_value=name.name)],
            header=[WhatsAppMessageTemplateBindingsComponent(ref_value=location.name)],
        )
        sample_movie_location.bindings = bindings
        sample_movie_location.template_values = [name, location]
        template_options = TemplateNotificationContent(
            channel_registration_id=self.channel_id, to=[self.phone_number], template=sample_movie_location
        )

        # calling send() with whatsapp message details
        message_responses = messaging_client.send(template_options)
        response = message_responses.receipts[0]
        print(
            "WhatsApp Location Templated Message with message id {} was successfully sent to {}".format(
                response.message_id, response.to
            )
        )


if __name__ == "__main__":
    sample = SendWhatsAppTemplateMessageSample()
    sample.send_template_send_message()
    sample.send_template_message_with_parameters()
    sample.send_template_message_with_buttons()
    sample.send_template_message_with_location()
    sample.send_template_message_with_call_to_action()
    sample.send_template_message_with_media()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models_py3 import (  # type: ignore
    AgentPool,
    AgentPoolAvailableVersions,
    AgentPoolAvailableVersionsPropertiesAgentPoolVersionsItem,
    AgentPoolListResult,
    AgentPoolUpgradeProfile,
    AgentPoolUpgradeProfilePropertiesUpgradesItem,
    BaseManagedCluster,
    CloudErrorBody,
    ContainerServiceDiagnosticsProfile,
    ContainerServiceLinuxProfile,
    ContainerServiceMasterProfile,
    ContainerServiceNetworkProfile,
    ContainerServiceSshConfiguration,
    ContainerServiceSshPublicKey,
    ContainerServiceVMDiagnostics,
    CredentialResult,
    CredentialResults,
    ManagedCluster,
    ManagedClusterAADProfile,
    ManagedClusterAPIServerAccessProfile,
    ManagedClusterAccessProfile,
    ManagedClusterAddonProfile,
    ManagedClusterAddonProfileIdentity,
    ManagedClusterAgentPoolProfile,
    ManagedClusterAgentPoolProfileProperties,
    ManagedClusterIdentity,
    ManagedClusterListResult,
    ManagedClusterLoadBalancerProfile,
    ManagedClusterLoadBalancerProfileManagedOutboundIPs,
    ManagedClusterLoadBalancerProfileOutboundIPPrefixes,
    ManagedClusterLoadBalancerProfileOutboundIPs,
    ManagedClusterPoolUpgradeProfile,
    ManagedClusterPoolUpgradeProfileUpgradesItem,
    ManagedClusterPropertiesAutoScalerProfile,
    ManagedClusterPropertiesIdentityProfileValue,
    ManagedClusterSKU,
    ManagedClusterServicePrincipalProfile,
    ManagedClusterUpgradeProfile,
    ManagedClusterWindowsProfile,
    OperationListResult,
    OperationValue,
    Resource,
    ResourceReference,
    SubResource,
    TagsObject,
    UserAssignedIdentity,
)

from ._container_service_client_enums import (  # type: ignore
    AgentPoolMode,
    AgentPoolType,
    ContainerServiceStorageProfileTypes,
    ContainerServiceVMSizeTypes,
    Count,
    LoadBalancerSku,
    ManagedClusterSKUName,
    ManagedClusterSKUTier,
    NetworkMode,
    NetworkPlugin,
    NetworkPolicy,
    OSType,
    OutboundType,
    ResourceIdentityType,
    ScaleSetEvictionPolicy,
    ScaleSetPriority,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AgentPool",
    "AgentPoolAvailableVersions",
    "AgentPoolAvailableVersionsPropertiesAgentPoolVersionsItem",
    "AgentPoolListResult",
    "AgentPoolUpgradeProfile",
    "AgentPoolUpgradeProfilePropertiesUpgradesItem",
    "BaseManagedCluster",
    "CloudErrorBody",
    "ContainerServiceDiagnosticsProfile",
    "ContainerServiceLinuxProfile",
    "ContainerServiceMasterProfile",
    "ContainerServiceNetworkProfile",
    "ContainerServiceSshConfiguration",
    "ContainerServiceSshPublicKey",
    "ContainerServiceVMDiagnostics",
    "CredentialResult",
    "CredentialResults",
    "ManagedCluster",
    "ManagedClusterAADProfile",
    "ManagedClusterAPIServerAccessProfile",
    "ManagedClusterAccessProfile",
    "ManagedClusterAddonProfile",
    "ManagedClusterAddonProfileIdentity",
    "ManagedClusterAgentPoolProfile",
    "ManagedClusterAgentPoolProfileProperties",
    "ManagedClusterIdentity",
    "ManagedClusterListResult",
    "ManagedClusterLoadBalancerProfile",
    "ManagedClusterLoadBalancerProfileManagedOutboundIPs",
    "ManagedClusterLoadBalancerProfileOutboundIPPrefixes",
    "ManagedClusterLoadBalancerProfileOutboundIPs",
    "ManagedClusterPoolUpgradeProfile",
    "ManagedClusterPoolUpgradeProfileUpgradesItem",
    "ManagedClusterPropertiesAutoScalerProfile",
    "ManagedClusterPropertiesIdentityProfileValue",
    "ManagedClusterSKU",
    "ManagedClusterServicePrincipalProfile",
    "ManagedClusterUpgradeProfile",
    "ManagedClusterWindowsProfile",
    "OperationListResult",
    "OperationValue",
    "Resource",
    "ResourceReference",
    "SubResource",
    "TagsObject",
    "UserAssignedIdentity",
    "AgentPoolMode",
    "AgentPoolType",
    "ContainerServiceStorageProfileTypes",
    "ContainerServiceVMSizeTypes",
    "Count",
    "LoadBalancerSku",
    "ManagedClusterSKUName",
    "ManagedClusterSKUTier",
    "NetworkMode",
    "NetworkPlugin",
    "NetworkPolicy",
    "OSType",
    "OutboundType",
    "ResourceIdentityType",
    "ScaleSetEvictionPolicy",
    "ScaleSetPriority",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential
from azure.mgmt.chaos import ChaosManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-chaos
# USAGE
    python create_update_experiment.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = ChaosManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="6b052e15-03d3-4f17-b2e1-be7f07588291",
    )

    response = client.experiments.begin_create_or_update(
        resource_group_name="exampleRG",
        experiment_name="exampleExperiment",
        experiment={
            "identity": {"type": "SystemAssigned"},
            "location": "eastus2euap",
            "properties": {
                "selectors": [
                    {
                        "id": "selector1",
                        "targets": [
                            {
                                "id": "/subscriptions/6b052e15-03d3-4f17-b2e1-be7f07588291/resourceGroups/exampleRG/providers/Microsoft.Compute/virtualMachines/exampleVM/providers/Microsoft.Chaos/targets/Microsoft-VirtualMachine",
                                "type": "ChaosTarget",
                            }
                        ],
                        "type": "List",
                    }
                ],
                "steps": [
                    {
                        "branches": [
                            {
                                "actions": [
                                    {
                                        "duration": "PT10M",
                                        "name": "urn:csci:microsoft:virtualMachine:shutdown/1.0",
                                        "parameters": [{"key": "abruptShutdown", "value": "false"}],
                                        "selectorId": "selector1",
                                        "type": "continuous",
                                    }
                                ],
                                "name": "branch1",
                            }
                        ],
                        "name": "step1",
                    }
                ],
            },
        },
    ).result()
    print(response)


# x-ms-original-file: specification/chaos/resource-manager/Microsoft.Chaos/stable/2024-01-01/examples/CreateUpdateExperiment.json
if __name__ == "__main__":
    main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.devtestlabs import DevTestLabsClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-devtestlabs
# USAGE
    python global_schedules_create_or_update.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = DevTestLabsClient(
        credential=DefaultAzureCredential(),
        subscription_id="{subscriptionId}",
    )

    response = client.global_schedules.create_or_update(
        resource_group_name="resourceGroupName",
        name="labvmautostart",
        schedule={
            "properties": {
                "status": "Enabled",
                "taskType": "LabVmsStartupTask",
                "timeZoneId": "Hawaiian Standard Time",
                "weeklyRecurrence": {
                    "time": "0700",
                    "weekdays": ["Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
                },
            }
        },
    )
    print(response)


# x-ms-original-file: specification/devtestlabs/resource-manager/Microsoft.DevTestLab/stable/2018-09-15/examples/GlobalSchedules_CreateOrUpdate.json
if __name__ == "__main__":
    main()



import argparse
import os
import re

from typing import Dict, List

from ci_tools.parsing import ParsedSetup

additional_pr_triggers: Dict[str, List[str]] = {
    "azure-core":[
        "/sdk/servicebus/azure-servicebus",
        "/sdk/eventhub/azure-eventhub",
        "/sdk/tables/azure-data-tables",
        "/sdk/appconfiguration/azure-appconfiguration",
        "/sdk/keyvault/azure-keyvault-keys",
        "/sdk/identity/azure-identity",
        "/sdk/core/azure-mgmt-core",
        "/sdk/core/azure-core-experimental",
        "/sdk/core/azure-core-tracing-opentelemetry",
        "/sdk/core/azure-core-tracing-opencensus",
        # todo: this currently won't be included, as azure-cosmos needs some special construction
        # related to windows only + emulator
        # "/sdk/cosmos/azure-cosmos",
        "/sdk/ml/azure-ai-ml",
        "/sdk/documentintelligence/azure-ai-documentintelligence",
        "/sdk/ai/azure-ai-inference",
        "/sdk/textanalytics/azure-ai-textanalytics",
        "/sdk/translation/azure-ai-translation-document",
        "/sdk/compute/azure-mgmt-compute",
        "/sdk/communication/azure-communication-chat",
        "/sdk/communication/azure-communication-identity",
        "/sdk/storage/azure-storage-blob"
    ],
    "azure-mgmt-core": [
        "/sdk/compute/azure-mgmt-compute",
        "/sdk/network/azure-mgmt-network",
        "/sdk/resources/azure-mgmt-resource",
        "/sdk/keyvault/azure-mgmt-keyvault"
    ]
}

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Get package version details from the repo")
    parser.add_argument("-s", "--search_path", required=True, help="The scope of the search")
    args = parser.parse_args()

    # Use abspath for the os.walk because if setup parsing fails it often changes cwd which throws off the relative walk
    for root, dirs, files in os.walk(os.path.abspath(args.search_path)):
        if re.search(r"sdk[\\/][^\\/]+[\\/][^\\/]+$", root):
            if "setup.py" in files:
                try:
                    parsed = ParsedSetup.from_path(root)

                    dependent_packages = ""
                    if parsed.name in additional_pr_triggers:
                        dependent_packages = ",".join(additional_pr_triggers[parsed.name])

                    print(
                        "{0} {1} {2} {3} {4}".format(
                            parsed.name,
                            parsed.version,
                            parsed.is_new_sdk,
                            os.path.dirname(parsed.setup_filename),
                            dependent_packages
                        )
                    )
                except:
                    # Skip setup.py if the package cannot be parsed
                    pass



import argparse
import logging
from pathlib import Path
import os
from jinja2 import Environment, FileSystemLoader
from subprocess import check_call
from typing import Any
import json

_LOGGER = logging.getLogger(__name__)

_TEMPLATE = Path(__file__).resolve().parent / "template"
_TEMPLATE_TESTS = Path(__file__).resolve().parent / "template_tests"
_TEMPLATE_SAMPLES = Path(__file__).resolve().parent / "template_samples"
_TEMPLATE_CI = Path(__file__).resolve().parent / "template_ci"
_CONFIG_FILE = Path(__file__).resolve().parent / "../../swagger_to_sdk_config_dpg.json"


def check_parameters(
        output_folder: str,
) -> None:
    # check output_folder exists or not. If not, create it.
    output = Path(output_folder)
    if not os.path.exists(output):
        _LOGGER.info(f'{output} does not exist and try to create it')
        os.makedirs(output)
        _LOGGER.info(f'{output} is created')


def generate_ci(template_path: Path, folder_path: Path, package_name: str) -> None:
    ci = Path(folder_path, "ci.yml")
    service_name = folder_path.name
    safe_name = package_name.replace("-", "")
    if not ci.exists():
        env = Environment(loader=FileSystemLoader(template_path), keep_trailing_newline=True)
        template = env.get_template('ci.yml')
        content = template.render(package_name=package_name, service_name=service_name, safe_name=safe_name)
    else:
        with open(ci, "r") as file_in:
            content = file_in.readlines()
            for line in content:
                if package_name in line:
                    return
            content.append(f'    - name: {package_name}\n')
            content.append(f'      safeName: {safe_name}\n')
    with open(ci, "w") as file_out:
        file_out.writelines(content)


def generate_test_sample(template_path: Path, target_path: Path, **kwargs: Any) -> None:
    if not os.path.exists(target_path):
        os.makedirs(target_path)
    env = Environment(loader=FileSystemLoader(template_path), keep_trailing_newline=True)
    for template_name in env.list_templates():
        _LOGGER.info(f"generate file: {template_name}")
        template = env.get_template(template_name)
        result = template.render(**kwargs)
        with open(target_path / template_name, "w") as fd:
            fd.write(result)


def generate_swagger_readme(work_path: str, env: Environment, **kwargs: Any) -> Path:
    _LOGGER.info("Building swagger readme")
    # check path exists
    swagger_path = Path(work_path) / Path('swagger')
    if not os.path.exists(swagger_path):
        os.makedirs(swagger_path)

    # render file
    template = env.get_template('README.md')
    input_file = kwargs.pop("input_file", "").split(",")
    result = template.render(input_file=input_file, **kwargs)
    swagger_readme = swagger_path / Path('README.md')
    with open(swagger_readme, 'w') as fd:
        fd.write(result)
    return swagger_readme


def generate_toml_file(target_path: Path) -> None:
    with open(target_path / "sdk_packaging.toml", "w") as file_out:
        file_out.write("[packaging]\nauto_update = false\n")


def get_autorest_version() -> str:
    with open(_CONFIG_FILE, 'r') as file_in:
        config = json.load(file_in)
    autorest_use = " ".join(["--use=" + item for item in config["meta"]["autorest_options"]["use"]])
    return "--version={} {}".format(config["meta"]["autorest_options"]["version"], autorest_use)


def build_package(**kwargs) -> None:
    # prepare template render parameters
    output_folder = kwargs.get("output_folder")
    package_name = kwargs.get("package_name")
    namespace = package_name.replace('-', '.')
    kwargs['namespace'] = namespace
    kwargs['test_prefix'] = package_name.split('-')[-1]

    _LOGGER.info("Build start: %s", package_name)
    check_parameters(output_folder)

    # generate ci
    generate_ci(_TEMPLATE_CI, Path(output_folder).parent, package_name)

    # generate swagger readme
    env = Environment(loader=FileSystemLoader(_TEMPLATE), keep_trailing_newline=True)
    swagger_readme = generate_swagger_readme(output_folder, env, **kwargs)

    # generate code with autorest and swagger readme
    autorest_cmd = f'autorest {swagger_readme} {get_autorest_version()} '
    _LOGGER.info(f"generate SDK code with autorest: {autorest_cmd}")
    check_call(autorest_cmd, shell=True)


    # generate test framework
    work_path = Path(output_folder)
    generate_test_sample(_TEMPLATE_TESTS, work_path / Path('tests'), **kwargs)

    # generate sample framework
    generate_test_sample(_TEMPLATE_SAMPLES, work_path / Path('samples'), **kwargs)

    # generate .toml file to avoid udpate_pr in CI
    generate_toml_file(work_path)

    _LOGGER.info("Build complete: %s", package_name)


def validate_params(**kwargs):
    if not kwargs.get("security_scope") and not kwargs.get("security_header_name"):
        raise Exception('At least one of "security-scope" and "security-header-name" is needed')


def main(**kwargs):
    build_package(**kwargs)


if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description="build package for Azure SDK of data-plane for Python",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    parser.add_argument(
        "--output-folder", "-o",
        dest="output_folder",
        required=True,
        help="absolute path where generated SDK package will be put"
    )
    parser.add_argument("--debug", dest="debug", action="store_true", help="Verbosity in DEBUG mode")
    parser.add_argument(
        "--input-file", "-f",
        dest="input_file",
        required=True,
        help="absolute path of swagger input file. For example: `https://raw.githubusercontent.com/Azure/azure-rest-api-specs/main/specification/webpubsub/data-plane/WebPubSub/stable/2021-10-01/webpubsub.json`"
             " or `D:\\azure-rest-api-specs\\specification\\webpubsub\\data-plane\\WebPubSub\\stable\\2021-10-01\\webpubsub.json`",
    )
    parser.add_argument(
        "--security-scope", "-c",
        dest="security_scope",
        required=False,
        help="If authentication is AADToken, this param is necessary",
    )
    parser.add_argument(
        "--security-header-name",
        dest="security_header_name",
        required=False,
        help="If authentication is api key, this param is necessary",
    )
    parser.add_argument(
        "--package-name", "-p",
        dest="package_name",
        required=True,
        help="package name. For example: azure-messaging-webpubsub",
    )
    parser.add_argument(
        "--package-pprint-name", "-n",
        dest="package_pprint_name",
        required=True,
        help="Print name of the package. For example: Azure Web PubSub Service",
    )
    parser.add_argument(
        "--client-name", "-t",
        dest="client_name",
        required=True,
        help="client name. For example: WebPubSubServiceClient",
    )

    args = parser.parse_args()
    main_logger = logging.getLogger()
    logging.basicConfig()
    main_logger.setLevel(logging.INFO)

    parameters = vars(args)
    validate_params(**parameters)
    main(**parameters)



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ClientAccessRight(Model):
    """The mapping between a particular client IP and the type of access client
    has on the NFS share.

    All required parameters must be populated in order to send to Azure.

    :param client: Required. IP of the client.
    :type client: str
    :param access_permission: Required. Type of access to be allowed for the
     client. Possible values include: 'NoAccess', 'ReadOnly', 'ReadWrite'
    :type access_permission: str or
     ~azure.mgmt.edgegateway.models.ClientPermissionType
    """

    _validation = {
        'client': {'required': True},
        'access_permission': {'required': True},
    }

    _attribute_map = {
        'client': {'key': 'client', 'type': 'str'},
        'access_permission': {'key': 'accessPermission', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ClientAccessRight, self).__init__(**kwargs)
        self.client = kwargs.get('client', None)
        self.access_permission = kwargs.get('access_permission', None)
